@@ -289,6 +289,16 @@ func TestNew(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "cpp conan-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.ConanaMetadataType,
+				Metadata: syftPkg.ConanMetadata{
+					Name:    "name",
+					Version: "version",
+				},
+			},
+		},
 	}
 
 	// capture each observed metadata type, we should see all of them relate to what syft provides by the end of testing
