@@ -28,6 +28,13 @@ var imagesWithVulnerabilities = []string{
 	"anchore/test_images:arch",
 }
 
+func getListingURL() string {
+	if value, ok := os.LookupEnv("GRYPE_DB_UPDATE_URL"); ok {
+		return value
+	}
+	return internal.DBUpdateURL
+}
+
 func TestCompareSBOMInputToLibResults(t *testing.T) {
 	formats := []sbom.FormatID{
 		syft.JSONFormatID,
@@ -36,9 +43,9 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 	}
 
 	// get a grype DB
-	vulnProvider, _, _, err := grype.LoadVulnerabilityDB(db.Config{
+	store, _, err := grype.LoadVulnerabilityDB(db.Config{
 		DBRootDir:           "test-fixtures/grype-db",
-		ListingURL:          internal.DBUpdateURL,
+		ListingURL:          getListingURL(),
 		ValidateByHashOnGet: false,
 	}, true)
 	assert.NoError(t, err)
@@ -54,6 +61,7 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 		string(syftPkg.DartPubPkg),
 		string(syftPkg.DotnetPkg),
 		string(syftPkg.PhpComposerPkg),
+		string(syftPkg.ConanPkg),
 		string(syftPkg.JenkinsPluginPkg), // package type cannot be inferred for all formats
 	)
 	observedPkgTypes := strset.New()
@@ -81,11 +89,11 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 				assert.NoError(t, sbomFile.Close())
 
 				// get vulns (sbom)
-				matchesFromSbom, _, pkgsFromSbom, err := grype.FindVulnerabilities(vulnProvider, fmt.Sprintf("sbom:%s", sbomFile.Name()), source.SquashedScope, nil)
+				matchesFromSbom, _, pkgsFromSbom, err := grype.FindVulnerabilities(*store, fmt.Sprintf("sbom:%s", sbomFile.Name()), source.SquashedScope, nil)
 				assert.NoError(t, err)
 
 				// get vulns (image)
-				matchesFromImage, _, _, err := grype.FindVulnerabilities(vulnProvider, imageSource, source.SquashedScope, nil)
+				matchesFromImage, _, _, err := grype.FindVulnerabilities(*store, imageSource, source.SquashedScope, nil)
 				assert.NoError(t, err)
 
 				// compare packages (shallow)
