@@ -4,12 +4,14 @@ import (
 	"testing"
 
 	"github.com/sergi/go-diff/diffmatchpatch"
+	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/grype/grype"
 	"github.com/anchore/grype/grype/db"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/matcher"
 	"github.com/anchore/grype/grype/pkg"
+	"github.com/anchore/grype/grype/store"
 	"github.com/anchore/grype/grype/vulnerability"
 	"github.com/anchore/grype/internal"
 	"github.com/anchore/stereoscope/pkg/imagetest"
@@ -26,7 +28,7 @@ func addAlpineMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Ca
 		t.Fatalf("problem with upstream syft cataloger (alpine)")
 	}
 	thePkg := pkg.New(packages[0])
-	theVuln := theStore.backend["alpine:3.12"][thePkg.Name][0]
+	theVuln := theStore.backend["alpine:distro:alpine:3.12"][thePkg.Name][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
@@ -60,13 +62,12 @@ func addJavascriptMatches(t *testing.T, theSource source.Source, catalog *syftPk
 		t.Fatalf("problem with upstream syft cataloger (javascript)")
 	}
 	thePkg := pkg.New(packages[0])
-	theVuln := theStore.backend["github:npm"][thePkg.Name][0]
+	theVuln := theStore.backend["github:language:javascript"][thePkg.Name][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
 	}
 	theResult.Add(match.Match{
-
 		Vulnerability: *vulnObj,
 		Package:       thePkg,
 		Details: []match.Detail{
@@ -95,7 +96,8 @@ func addPythonMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Ca
 		t.Fatalf("problem with upstream syft cataloger (python)")
 	}
 	thePkg := pkg.New(packages[0])
-	theVuln := theStore.backend["github:python"][thePkg.Name][0]
+	normalizedName := theStore.normalizedPackageNames["github:language:python"][thePkg.Name]
+	theVuln := theStore.backend["github:language:python"][normalizedName][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
@@ -130,7 +132,8 @@ func addDotnetMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Ca
 		t.Fatalf("problem with upstream syft cataloger (dotnet)")
 	}
 	thePkg := pkg.New(packages[0])
-	theVuln := theStore.backend["github:nuget"][thePkg.Name][0]
+	normalizedName := theStore.normalizedPackageNames["github:language:dotnet"][thePkg.Name]
+	theVuln := theStore.backend["github:language:dotnet"][normalizedName][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
@@ -162,7 +165,7 @@ func addRubyMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Cata
 		t.Fatalf("problem with upstream syft cataloger (ruby)")
 	}
 	thePkg := pkg.New(packages[0])
-	theVuln := theStore.backend["github:gem"][thePkg.Name][0]
+	theVuln := theStore.backend["github:language:ruby"][thePkg.Name][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
@@ -203,13 +206,12 @@ func addJavaMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Cata
 
 	thePkg := pkg.New(theSyftPkg)
 
-	theVuln := theStore.backend["github:java"][lookup][0]
+	theVuln := theStore.backend["github:language:java"][lookup][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
 	}
 	theResult.Add(match.Match{
-
 		Vulnerability: *vulnObj,
 		Package:       thePkg,
 		Details: []match.Detail{
@@ -236,7 +238,7 @@ func addDpkgMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Cata
 	}
 	thePkg := pkg.New(packages[0])
 	// NOTE: this is an indirect match, in typical debian style
-	theVuln := theStore.backend["debian:8"][thePkg.Name+"-dev"][0]
+	theVuln := theStore.backend["debian:distro:debian:8"][thePkg.Name+"-dev"][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
@@ -271,7 +273,7 @@ func addRhelMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Cata
 		t.Fatalf("problem with upstream syft cataloger (RPMDB)")
 	}
 	thePkg := pkg.New(packages[0])
-	theVuln := theStore.backend["rhel:8"][thePkg.Name][0]
+	theVuln := theStore.backend["redhat:distro:redhat:8"][thePkg.Name][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
@@ -306,7 +308,7 @@ func addSlesMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Cata
 		t.Fatalf("problem with upstream syft cataloger (RPMDB)")
 	}
 	thePkg := pkg.New(packages[0])
-	theVuln := theStore.backend["rhel:8"][thePkg.Name][0]
+	theVuln := theStore.backend["redhat:distro:redhat:8"][thePkg.Name][0]
 	vulnObj, err := vulnerability.NewVulnerability(theVuln)
 	if err != nil {
 		t.Fatalf("failed to create vuln obj: %+v", err)
@@ -417,7 +419,16 @@ func TestMatchByImage(t *testing.T) {
 
 			matchers := matcher.NewDefaultMatchers(matcher.Config{})
 
-			actualResults := grype.FindVulnerabilitiesForPackage(db.NewVulnerabilityProvider(theStore), theDistro, matchers, pkg.FromCatalog(theCatalog, pkg.ProviderConfig{}))
+			vp, err := db.NewVulnerabilityProvider(theStore)
+			require.NoError(t, err)
+			ep := db.NewMatchExclusionProvider(theStore)
+			store := store.Store{
+				Provider:          vp,
+				MetadataProvider:  nil,
+				ExclusionProvider: ep,
+			}
+
+			actualResults := grype.FindVulnerabilitiesForPackage(store, theDistro, matchers, pkg.FromCatalog(theCatalog, pkg.ProviderConfig{}))
 
 			// build expected matches from what's discovered from the catalog
 			expectedMatches := test.expectedFn(*theSource, theCatalog, theStore)
@@ -448,7 +459,6 @@ func TestMatchByImage(t *testing.T) {
 					diffs := dmp.DiffMain(value, aMatch.String(), true)
 					t.Errorf("mismatched output:\n%s", dmp.DiffPrettyText(diffs))
 				}
-
 			}
 
 			if expectedCount != actualCount {
